Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(574)

Unified Diff: runtime/include/dart_debugger_api.h

Issue 13975018: More cleanups in debugger API and wire protocol (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/dbg_message.cc ('k') | runtime/vm/debugger_api_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_debugger_api.h
===================================================================
--- runtime/include/dart_debugger_api.h (revision 21365)
+++ runtime/include/dart_debugger_api.h (working copy)
@@ -44,6 +44,17 @@
kShutdown,
} Dart_IsolateEvent;
+
+/**
+ * Represents a location in Dart code.
+ */
+typedef struct {
+ Dart_Handle script_url; // Url (string) of the script.
+ int32_t library_id; // Library in which the script is loaded.
+ int32_t token_pos; // Code address.
Tom Ball 2013/04/12 21:44:32 Line up comment?
hausner 2013/04/12 21:48:09 Done.
+} Dart_CodeLocation;
+
+
typedef void Dart_IsolateEventHandler(Dart_IsolateId isolate_id,
Dart_IsolateEvent kind);
@@ -362,6 +373,8 @@
/**
+ * DEPRECATED -- Use Dart_ActivationframeGetLocation instead.
+ *
* Returns information about the given activation frame.
* \function_name receives a string handle with the qualified
* function name.
@@ -386,15 +399,20 @@
/**
* Returns text location of the given activation frame.
* \script_url receives a string handle with the url of the
* source script that contains the frame's function.
Tom Ball 2013/04/12 21:44:32 locatin => location
hausner 2013/04/12 21:48:09 Done.
+ * the source script that contains the frame's function.
* Receives a null handle if there is no textual location
* that corresponds to the frame, e.g. for implicitly
* generated constructors.
- * \token_number receives the line number in the script.
+ * \location.library_id receives the id of the library in which the
+ * function in this frame is defined.
+ * \location.token_pos receives the token position in the script.
*
- * Any or all of the out parameters above may be NULL.
+ * Any of the out parameters above may be NULL.
*
* Requires there to be a current isolate.
*
@@ -404,9 +422,8 @@
*/
DART_EXPORT Dart_Handle Dart_ActivationFrameGetLocation(
Dart_ActivationFrame activation_frame,
- Dart_Handle* script_url,
- intptr_t* library_id,
- intptr_t* token_number);
+ Dart_Handle* function_name,
+ Dart_CodeLocation* location);
/**
« no previous file with comments | « runtime/bin/dbg_message.cc ('k') | runtime/vm/debugger_api_impl.cc » ('j') | no next file with comments »
@@ -386,15 +399,20 @@
/**
- * Returns text location of the given activation frame.
- * \script_url receives a string handle with the url of the
- * source script that contains the frame's function.
+ * Returns code location of the given activation frame.
+ *
+ * \function_name receives a string handle with the qualified
+ * function name.
+ * \locatin.script_url receives a string handle with the url of
Tom Ball 2013/04/12 21:44:32 locatin => location
hausner 2013/04/12 21:48:09 Done.

Powered by Google App Engine
This is Rietveld 408576698